Module log

Module log 

Available on (crate features logging or metrics or telemetry or tracing) and crate feature logging only.
Logging-related functionality.

Modules

log_volumemetrics
rustfoundry::telemetry::log::log_volume_metrics provides metrics collection based on log volume.

Macros

add_fields
Adds fields to all the log records, making them context fields.
debug
Log debug level record.
error
Log error level record.
info
Log info level record.
trace
Log trace level record.
warn
Log warning level record.

Structs

TestLogRecordtesting
Log record produced in the test telemetry context.

Functions

set_verbosity
Sets current log’s verbosity, overriding the settings used in init.
slog_logger
Returns current log as a raw slog crate’s Logger used by Rustfoundry internally.
verbosity
Gets the current log’s verbosity.